--AH:ScriptId=26e27dc6-5406-4502-88cb-8b212b1e1c63;3213
DROP TABLE [ExecutionLogEntries]
DROP TABLE [ScheduledTaskExecutions]
DROP TABLE [FeedSyncExecutions]
DROP TABLE [Executions]
GO

CREATE TABLE [Executions]
(
	[Execution_Id] INT IDENTITY(1, 1) NOT NULL,
	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,
	[ExecutionStatus_Code] CHAR(1) NOT NULL,
	[ExecutionRunState_Code] CHAR(1) NOT NULL,
	[ExecutionMode_Code] CHAR(1) NOT NULL,
	[CreatedBy_User_Name] USERNAME NOT NULL,
	[CreatedOn_Date] DATETIME NOT NULL,
	[CanceledBy_User_Name] USERNAME NULL,
	[CanceledOn_Date] DATETIME NULL,
	[ExecutionType_Name] VARCHAR(50) NULL,
	[Execution_Configuration] XML NULL,
	[ScheduledTask_Id] INT NULL,
	[Feed_Id] INT NULL,
	[Connector_Id] INT NULL,

	CONSTRAINT [PK__Executions]
		PRIMARY KEY([Execution_Id]),

	CONSTRAINT [FK__Executions__ScheduledTasks]
		FOREIGN KEY ([ScheduledTask_Id])
		REFERENCES [ScheduledTasks] ([ScheduledTask_Id]),

	CONSTRAINT [FK__Executions__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE,

	CONSTRAINT [FK__Executions__Connectors]
		FOREIGN KEY ([Connector_Id])
		REFERENCES [Connectors] ([Connector_Id])
		ON DELETE CASCADE,

	CONSTRAINT [CK__Executions__ExecutionRunState_Code]
		CHECK ([ExecutionRunState_Code] IN ('C', 'X', 'P')),

	CONSTRAINT [CK__Executions__ExecutionStatus_Code]
		CHECK ([ExecutionStatus_Code] IN ('E', 'W', 'S'))
)

CREATE NONCLUSTERED INDEX [IX__Executions__ScheduledTasks]
	ON [Executions] ([ScheduledTask_Id])
	INCLUDE ([Start_Date], [ExecutionStatus_Code], [ExecutionRunState_Code])

CREATE TABLE [ScopedExecutionLogs]
(
	[Execution_Id] INT NOT NULL,
	[Scope_Sequence] INT NOT NULL,
	[Parent_Scope_Sequence] INT NULL,
	[Scope_Name] VARBINARY(MAX) NOT NULL,
	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,
	[HighestLogEntry_Level] INT NULL,

	CONSTRAINT [PK__ScopedExecutionLogs]
		PRIMARY KEY ([Execution_Id], [Scope_Sequence]),

	CONSTRAINT [FK__ScopedExecutionLogs__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id])
		ON DELETE CASCADE,

	CONSTRAINT [FK__ScopedExecutionLogs__ScopedExecutionLogs]
		FOREIGN KEY ([Execution_Id], [Parent_Scope_Sequence])
		REFERENCES [ScopedExecutionLogs] ([Execution_Id], [Scope_Sequence]),

	CONSTRAINT [CK__ScopedExecutionLogs__Parent_Scope_Sequence]
		CHECK ([Parent_Scope_Sequence] IS NULL OR [Parent_Scope_Sequence]<>[Scope_Sequence]),

	CONSTRAINT [CK__ScopedExecutionLogs__Scope_Sequence]
		CHECK ([Scope_Sequence]>0)
)

CREATE TABLE [ScopedExecutionLogEntries]
(
	[Execution_Id] INT NOT NULL,
	[LogEntry_Sequence] INT NOT NULL,
	[Scope_Sequence] INT NOT NULL,
	[LogEntry_Level] INT NOT NULL,
	[LogEntry_Text] VARBINARY(MAX) NOT NULL,
	[LogEntry_Date] DATETIME NOT NULL,

	CONSTRAINT [PK__ScopedExecutionLogEntries]
		PRIMARY KEY ([Execution_Id], [LogEntry_Sequence]),

	CONSTRAINT [FK__ScopedExecutionLogEntries__ScopedExecutionLogs]
		FOREIGN KEY ([Execution_Id], [Scope_Sequence])
		REFERENCES [ScopedExecutionLogs] ([Execution_Id], [Scope_Sequence])
		ON DELETE CASCADE,

	CONSTRAINT [CK__ScopedExecutionLogEntries__LogEntry_Sequence]
		CHECK ([LogEntry_Sequence]>0)
)
